@@ -440,18 +440,9 @@ def listproj():
                 projects.append(folder)
     click.echo(Fore.GREEN + "> Projects in this directory: " + str(projects) + Fore.RESET)
 
-def uninstall():
+def pie_uninstall():
     """Deletes Config and other Directories created by this project, in order to update to pie-rust"""
     fileio.del_config()
-    if os.name == 'nt':
-        # Windows
-        PATH = str(Path(os.getenv('APPDATA') + '\\pie_manager'))
-    else:
-        # Linux
-        PATH = str(Path.home()) + '/pie_manager'
-
-    shutil.rmtree(PATH)
-    print(f"{Fore.GREEN}Removed Config folder{Fore.RESET}")
 
 @main.command()
 def changelog():
@@ -459,8 +450,8 @@ def changelog():
     click.echo(fileio.changelog)
 
 def register_commands():
-    in_project_commands = [run, install, uninstall, plist, show, pip, ver, reqs, push, autoinstall]
-    out_project_commands = [pkg, unpkg, cfg, new, listproj, delete_project]
+    in_project_commands = [run, install, uninstall, plist, show, pip, ver, reqs, push, autoinstall, pie_uninstall]
+    out_project_commands = [pkg, unpkg, cfg, new, listproj, delete_project, pie_uninstall]
     if is_in_project():
         for command in in_project_commands:
             if command == plist:
